@@ -124,6 +124,7 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
     sessBox->addItem ( "KDE" );
     sessBox->addItem ( "GNOME" );
     sessBox->addItem ( "LXDE" );
+    sessBox->addItem ( "UNITY" );
     sessBox->addItem ( tr ( "Connect to Windows terminal server" ) );
     sessBox->addItem ( tr ( "XDMCP" ) );
     sessBox->addItem ( tr ( "Connect to local desktop" ) );
@@ -391,6 +392,11 @@ void SessionWidget::readConfig()
             sessBox->setCurrentIndex ( LXDE );
             cmd->setEnabled ( false );
         }
+        else if ( command=="UNITY" )
+        {
+            sessBox->setCurrentIndex ( UNITY );
+            cmd->setEnabled ( false );
+        }
         else if ( command=="SHADOW" )
         {
             sessBox->setCurrentIndex ( SHADOW );
