@@ -1,7 +1,7 @@
 
 /***************************************************************************
- *   Copyright (C) 2005-2012 by Oleksandr Shneyder   *
- *   oleksandr.shneyder@obviously-nice.de   *
+ *   Copyright (C) 2005-2012 by Oleksandr Shneyder                         *
+ *   oleksandr.shneyder@obviously-nice.de                                  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -46,6 +46,9 @@
 #undef DEBUG
 //#define DEBUG
 
+//#define SSH_DEBUG
+#undef SSH_DEBUG
+
 static bool isLibSshInited=false;
 
 
@@ -142,7 +145,12 @@ void SshMasterConnection::run()
     }
 #endif
 
-//     int verbosity=SSH_LOG_PROTOCOL;
+#ifdef SSH_DEBUG
+    int verbosity=SSH_LOG_PACKET;
+#else
+    int verbosity=SSH_LOG_NOLOG;
+#endif
+
     long timeout = 60;
 
     my_ssh_session = ssh_new();
@@ -159,7 +167,7 @@ void SshMasterConnection::run()
 #ifdef Q_OS_WIN
     ssh_options_set ( my_ssh_session, SSH_OPTIONS_SSH_DIR, (mainWnd->getHomeDirectory()+"/ssh").toAscii());
 #endif
-//     ssh_options_set(my_ssh_session, SSH_OPTIONS_LOG_VERBOSITY, &verbosity);
+    ssh_options_set(my_ssh_session, SSH_OPTIONS_LOG_VERBOSITY, &verbosity);
 
     ssh_options_set(my_ssh_session, SSH_OPTIONS_TIMEOUT, &timeout);
 
@@ -277,7 +285,8 @@ void SshMasterConnection::finalizeLibSsh()
 bool SshMasterConnection::sshConnect()
 {
     int rc;
-    ssh_options_set ( my_ssh_session, SSH_OPTIONS_HOST, host.toAscii() );
+    QByteArray tmpBA = host.toLocal8Bit();
+    ssh_options_set ( my_ssh_session, SSH_OPTIONS_HOST, tmpBA.data() );
     ssh_options_set ( my_ssh_session, SSH_OPTIONS_PORT, &port );
     rc = ssh_connect ( my_ssh_session );
     if ( rc != SSH_OK )
